@@ -349,6 +349,11 @@ void KStarsData::setLocation( const GeoLocation &l ) {
     Options::setElevation( m_Geo.height() );
     Options::setLongitude( m_Geo.lng()->Degrees() );
     Options::setLatitude( m_Geo.lat()->Degrees() );
+    // set the rule from rulebook
+    foreach( const QString& key, Rulebook.keys() ) {
+        if( !key.isEmpty() && m_Geo.tzrule()->equals(&Rulebook[key]) )
+            Options::setDST(key);
+    }
 
     emit geoChanged();
 }
